#ifndef ABOUTDLG_H
#define ABOUTDLG_H

#include <QDialog>

class QWidget;

class AboutDlg : public QDialog
{
    Q_OBJECT
public:
    AboutDlg(QWidget *parent = 0);
};

#endif

